@@ -1,4 +1,4 @@
-/*  $Id: BurgerSpaceClient.cpp,v 1.5 2013/02/25 05:04:43 sarrazip Exp $
+/*  $Id: BurgerSpaceClient.cpp,v 1.7 2017/12/09 04:29:00 sarrazip Exp $
     BurgerSpaceClient.cpp - Game client
 
     burgerspace - A hamburger-smashing video game.
@@ -209,7 +209,7 @@ BurgerSpaceClient::processActivation(bool appActive)
 
 
 void
-BurgerSpaceClient::loadPixmaps() throw(PixmapLoadError)
+BurgerSpaceClient::loadPixmaps()
 {
     /*  Tiles:
     */
@@ -801,7 +801,7 @@ BurgerSpaceClient::showSlotDirectory()
         const char *leftCursor  = (slotNum == slotDirCursorPos ? "->" : "  ");
         const char *rightCursor = (slotNum == slotDirCursorPos ? "<-" : "  ");
         snprintf(slotDesc, sizeof(slotDesc), " %s  %u  %-19s %s ",
-                 leftCursor, slotNum, fileTime, rightCursor);
+                 leftCursor, unsigned(slotNum), fileTime, rightCursor);
         writeStringXCentered(string(slotDesc), y += fontHeight);
     }
 
