@@ -1,4 +1,4 @@
-/*  $Id: EnemySprite.cpp,v 1.9 2010/05/26 03:13:01 sarrazip Exp $
+/*  $Id: EnemySprite.cpp,v 1.10 2017/12/09 04:29:00 sarrazip Exp $
     EnemySprite.cpp - Sprite that represents an enemy of the player.
 
     burgerspace - A hamburger-smashing video game.
@@ -29,7 +29,7 @@ using namespace flatzebra;
 
 EnemySprite::EnemySprite(const PixmapArray &pa,
                             Couple pos, Couple speed,
-                            Couple collBoxPos, Couple collBosSize) throw(int)
+                            Couple collBoxPos, Couple collBosSize)
   : Sprite(pa, pos, speed, Couple(0, 0), collBoxPos, collBosSize),
     carryingGroup(NULL),
     disappearanceTime(0),
