@@ -1,4 +1,4 @@
-/*  $Id: RemoteServer.cpp,v 1.4 2010/11/18 05:35:02 sarrazip Exp $
+/*  $Id: RemoteServer.cpp,v 1.5 2012/10/07 21:29:24 sarrazip Exp $
     RemoteServer.cpp - UDP server
 
     burgerspace - A hamburger-smashing video game.
@@ -32,6 +32,8 @@
 
 #ifdef _MSC_VER
 #include <io.h>  // for close()
+#else
+#include <unistd.h>  // for close()
 #endif
 
 
