@@ -1,4 +1,4 @@
-/*  $Id: client.cpp,v 1.5 2010/11/18 05:35:02 sarrazip Exp $
+/*  $Id: client.cpp,v 1.6 2019/08/08 23:09:29 sarrazip Exp $
     client.cpp - main() function for BurgerSpace
 
     burgerspace - A hamburger-smashing video game.
@@ -292,6 +292,17 @@ main(int argc, char *argv[])
     #endif  /* defined(_MSC_VER) */
 
 
+    /*  Initialize the random number generator:
+    */
+    const char *s = getenv("SEED");
+    unsigned int seed = (unsigned int) (s != NULL ? atol(s) : time(NULL));
+    #ifndef NDEBUG
+    cerr << "seed = " << seed << endl;
+    cerr << "init-level-no = " << initLevelNo << endl;
+    #endif
+    srand(seed);
+
+
     try
     {
         bool standAlone = serverHostname.empty();
